---
name: Question
about: General questions, bugs or feedback.
title: ''
labels: ''
assignees: ''

---

Either Spanish or English is equally fine. 🤷

If you have a question about usage, or something simple, please check existing issues.
Many of the most common questions have already been asked before.

If you came across a bug: please include a sample of the failing code, and backtrace.

```python
# If pasting code, please do it between three backticks so that the format is readable.
# This whole block and code is rendered as code.
if answer == 42:
    return True
```

Also be sure to include the output of `pip freeze`.
